==> spellathon-5.34.tar.gz: spellathon-5.34/src/logic/solver.h <==
/*
 * Copyright (c) 2009, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * The names of its contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#ifndef _SOLVER_H_
#define _SOLVER_H_

#include <vector>
#include <string>
#include <limits.h>

#include "defines.h"

using std::vector;
using std::string;

namespace Spellathon
{
	class Dict;
	
	class Solver {
	public:
		Solver(const Dict *d) : dict(d) { wordPtrs.reserve(256); words_.reserve(256); }
		int	solve(const char *letrs, int min = 0, int max = INT_MAX);
		const vector<string> & words(); 
		int nwords() const { return wordPtrs.size(); }

	private:
		const Dict	*dict;
		vector<char*>	wordPtrs;
		vector<string>	words_;

	private:
		int	signGen(const char *letters, char signarr[][MAX_LETRS+1]);
	};
	
}

#endif /* _SOLVER_H_ */

==> spellathon-5.40.tar.gz: spellathon-5.40/src/logic/solver.h <==
/*
 * Copyright (c) 2009, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * The names of its contributors may be used to endorse or promote products 
 * derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#ifndef _SOLVER_H_
#define _SOLVER_H_

#include <vector>
#include <string>
#include <limits.h>

#include "defines.h"

using std::vector;
using std::string;

namespace Spellathon
{
	class Dict;
	
	class Solver {
	public:
		Solver(const Dict *d, bool plural_sieve) 
		  : plural_sieve_(plural_sieve), dict(d) { wordPtrs.reserve(256); words_.reserve(256); }
		int	solve(const char *letrs, int min = 0, int max = INT_MAX);
		const vector<string> & words(); 
		int nwords() const { return wordPtrs.size(); }
		void setPluralSieve(bool e) { plural_sieve_ = e; }
	private:
		bool plural_sieve_;
		const Dict	*dict;
		vector<char*>	wordPtrs;
		vector<string>	words_;
	private:
		int	signGen(const char *letters, char signarr[][MAX_LETRS+1]);
	};
	
}

#endif /* _SOLVER_H_ */
